==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/HighlightingInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { HighlightingInfoDescription } from "./HighlightingInfoDescription";
/**
 * @hidden
 */
export let HighlightingInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class HighlightingInfoDescriptionMetadata extends Base {
        static b(a) {
            if (HighlightingInfoDescriptionMetadata.a == null) {
                HighlightingInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HighlightingInfoDescriptionMetadata.c(HighlightingInfoDescriptionMetadata.a);
            }
            if (a.j(HighlightingInfoDescriptionMetadata.a)) {
                return;
            }
            a.y(HighlightingInfoDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("StartIndex", "Number:int");
            a.item("EndIndex", "Number:int");
            a.item("State", "ExportedType:string:HighlightingState");
            a.item("State@names", "Outward;Inward;Static");
            a.item("Progress", "Number:double");
            a.item("IsMarker", "Boolean");
            a.item("IsFullRange", "Boolean");
            a.item("IsExclusive", "Boolean");
            a.item("Series", "ExportedType:Series");
        }
        static d(a) {
            HighlightingInfoDescriptionMetadata.b(a);
            a.aa("HighlightingInfo", () => new HighlightingInfoDescription());
            a.z("HighlightingInfo", HighlightingInfoDescriptionMetadata.a);
        }
    }
    HighlightingInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(HighlightingInfoDescriptionMetadata, 'HighlightingInfoDescriptionMetadata');
    HighlightingInfoDescriptionMetadata.a = null;
    return HighlightingInfoDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/HighlightingInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { HighlightingInfoDescription } from "./HighlightingInfoDescription";
/**
 * @hidden
 */
export let HighlightingInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class HighlightingInfoDescriptionMetadata extends Base {
        static b(a) {
            if (HighlightingInfoDescriptionMetadata.a == null) {
                HighlightingInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HighlightingInfoDescriptionMetadata.c(HighlightingInfoDescriptionMetadata.a);
            }
            if (a.k(HighlightingInfoDescriptionMetadata.a)) {
                return;
            }
            a.aa(HighlightingInfoDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("StartIndex", "Number:int");
            a.item("EndIndex", "Number:int");
            a.item("State", "ExportedType:string:HighlightingState");
            a.item("State@names", "Outward;Inward;Static");
            a.item("Progress", "Number:double");
            a.item("IsMarker", "Boolean");
            a.item("IsFullRange", "Boolean");
            a.item("IsExclusive", "Boolean");
            a.item("Series", "ExportedType:Series");
        }
        static d(a) {
            HighlightingInfoDescriptionMetadata.b(a);
            a.ac("HighlightingInfo", () => new HighlightingInfoDescription());
            a.ab("HighlightingInfo", HighlightingInfoDescriptionMetadata.a);
        }
    }
    HighlightingInfoDescriptionMetadata.$t = /*@__PURE__*/ markType(HighlightingInfoDescriptionMetadata, 'HighlightingInfoDescriptionMetadata');
    HighlightingInfoDescriptionMetadata.a = null;
    return HighlightingInfoDescriptionMetadata;
})();
